@@ -74,13 +74,14 @@ def handle_call_schedulemanager():
     _, project_to_config = get_master_config()
     for project in project_to_config:
         client = cdf.experimental_client(project)
-        function_asset = client.functions.retrieve(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID)
-        air_functions_asset = client.functions.retrieve(external_id=const.AIR_FUNCTIONS_SCHEDULEMANAGER_EXTERNAL_ID)
-        if function_asset is not None:
-            client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
-        elif air_functions_asset is not None:
-            client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
-        else:
+        called = 0
+        for schedulemanager_external_id in const.SCHEDULE_MANAGER_EXTERNAL_IDS:
+            function_asset = client.functions.retrieve(external_id=schedulemanager_external_id)
+            if function_asset is not None:
+                client.functions.call(external_id=schedulemanager_external_id, wait=False)
+                called = 1
+                break
+        if called == 0:
             raise ValueError("No schedule manager has been deployed in air-functions or air-ds-infrastructure!")
 
 
